#
# spec file for package python-rtslib
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define oname rtslib

Name:           python-rtslib
Summary:        A framework to implement simple but nice CLIs
License:        Apache-2.0
Group:          Development/Languages/Python
Version:        3.0pre4
Release:        34.39
Url:            https://github.com/Datera/rtslib
Source:         %{oname}-%{version}.tar.gz
Patch1:         %{oname}-set-git-version-for-sle12.patch
Patch2:         %{oname}-add-prot-info-attributes.patch
Patch5:         0001-Add-support-for-xen-scsiback.patch
Patch6:         %{oname}-fix-iqn-wwn.patch
Patch7:         %{oname}-disallow-upper-case-iqn-names.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       python-configobj
Requires:       python-ipaddr
Requires:       python-netifaces
Requires:       python-pyparsing
BuildRequires:  python-configobj
BuildRequires:  python-devel
BuildRequires:  python-ipaddr
BuildRequires:  python-netifaces
BuildRequires:  python-pyparsing
BuildRequires:  python-setuptools

%description
API for RisingTide Systems generic SCSI target.
RTSlib is a Python library that provides an API to the LIO Linux SCSI Target,
and its third-party target fabric modules and backend storage objects.

RTSlib was developed by Datera, Inc. (www.daterainc.com). It is useful for
developing 3rd-party applications, and as a foundation for the Datera
userspace tools.

For more information, please see the targetcli User's Guide at:
http://linux-iscsi.org/wiki/targetcli

and the RTSlib API Reference Guide at:
http://linux-iscsi.org/Doc/rtslib/html
http://linux-iscsi.org/Doc/rtslib/rtslib-API-reference.pdf


%package doc
Summary:        Documentatoin for Python rtslib-fb
Group:          Documentation/HTML
BuildArch:      noarch
BuildRequires:  epydoc

%description doc
This is the documents for python rtslib sub pacakge.

%prep
%setup -q -n %{oname}-%{version}
%patch1 -p1
%patch2 -p1
%patch5 -p1
%patch6 -p1
%patch7	-p1

%build
%__python setup.py build
%__mkdir -p doc
epydoc --no-sourcecode --html -n %{oname} --exclude configobj %{oname}/*.py
%__mv html doc/

%install
%__python setup.py install --skip-build --root %{buildroot} --prefix usr

%__install -d  %{buildroot}%{_localstatedir}/target/pr
%__install -d  %{buildroot}%{_localstatedir}/target/alua
%__install -d  %{buildroot}%{_localstatedir}/target/fabric
%__install -m644 specs/*.spec %{buildroot}%{_localstatedir}/target/fabric
%__install -d %{buildroot}%{_localstatedir}/target/policy
%__install -m644 policy/*.lio %{buildroot}%{_localstatedir}/target/policy
%__install -d %{buildroot}%{_datadir}/doc/python-rtslib-doc-%{version}
%__cp -r doc/* specs/*.txt %{buildroot}%{_datadir}/doc/python-rtslib-doc-%{version}/

%files
%defattr(-,root,root,-)
%{python_sitelib}
%{_localstatedir}/target

%dir %{_localstatedir}/target/pr
%dir %{_localstatedir}/target/alua
%dir %{_localstatedir}/target/fabric
%{_localstatedir}/target/fabric/*
%dir %{_localstatedir}/target/policy
%{_localstatedir}/target/policy/*

%doc COPYING README.md

%files doc
%defattr(-,root,root,-)
%{_datadir}/doc/python-rtslib-doc-%{version}

%changelog
* Sun Jun 12 2016 lszhu@suse.com
- Fix BNC#968745 - targetcli can create targets with uppercase
  letters causing lio-utils problems
- Add patch: rtslib-disallow-upper-case-iqn-names.patch
* Fri May 13 2016 lszhu@suse.com
- Update to version 3.0 pre4
- Remove rtslib-git-update.patch, because this package is already
  updated to latest git release.
- Remove rtslib-add-iblock-backstore-policy.patch, because it is
  already in version per4 release, and the values in
  /policy/backstore_iblock.lio have been changed to the values
  in the patch.
- Change version to 3.0pre4-suse
* Fri Dec 25 2015 lszhu@suse.com
- fix BNC#958274 - Wrong random default name of iSCSI target name
  generated by Targetcli
  fix iqn wwn name error when include "-"
  patch: rtslib-fix-iqn-wwn.patch
* Wed Mar  4 2015 olaf@aepfle.de
- Add support for xen-scsiback (fate#315712)
  0001-Add-support-for-xen-scsiback.patch
* Fri Feb 27 2015 olaf@aepfle.de
- Use /var/lib/target in SLE11 to pass old FHS checks
* Wed Aug  6 2014 lduncan@suse.com
- Added iblock backstore policy file (bnc#885565), so
  targetcli does not backtrace when creating same, adding
  rtslib-add-iblock-backstore-policy.patch
* Fri Jun 27 2014 lduncan@suse.com
  Updated to match SLE 12 changes:
- Added T10 Protection Information attributes (bnc#880355):
  rtslib-add-prot-info-attributes.patch
- Added patch to set GIT_VERSION string (bnc#880355):
  rtslib-set-git-version-for-sle12.patch
- Updated spec file:
  - use new patches
  - create and populate /var/target tree
* Mon May 19 2014 hare@suse.de
- Add pyparsing to requires
- README got renamed to README.md
* Fri May 16 2014 hare@suse.de
- Update to latest git commit
  * Update README
  * Minor fixes
  * Add support for nullio ramdisks
  * Update copyright notice
  * Build fixes
  * Add rtslib-git-update.patch
* Wed Dec 18 2013 hare@suse.de
- Update to version 2.2 from github repository:
  * targetcli moved into separate package
  * Removed references to targetcli program and manpages
- Update description
- Change license tag to correct one; rtslib is licensed under Apache-2.0
- Add missing dependencies to get it fully working
* Sun Nov 24 2013 p.drouand@gmail.com
- Change tarball download location to new official one
- Update to version 2.1.fb42
  + No changelog available
- Remove rtslib-qla2xxx-fix.patch; merged on upstream release
- Add man pages for targetcli
* Wed Oct 16 2013 hare@suse.de
- Fixup typo in fabric.py (bnc#837519)
* Wed Feb 27 2013 saschpe@suse.de
- Replace this with the official version from PyPI and redo the spec file:
  + Drop useless (build) requires
  + Drop even more useless doc sub-package
  + Drop patches that are upstream
* Thu Jan 17 2013 hare@suse.de
- Initial commit from git repository
